****************
Related Packages
****************

We're big fans of open-source software at ``climpred`` and want to support and
collaborate with any other forecasting-related packages.
Below is a list of packages that have some place in the Earth System forecasting
world. Please reach out to us if you are aware of any open-source packages in this
domain that are not on the list.

* `Microsoft forecasting <https://microsoft.github.io/forecasting/>`_:
  A collection of best practices for time series forecasting.
* `MurCSS <https://github.com/illing2005/murcss>`_:
  A tool for standardized evaluation of decadal hindcast systems. See also
  `this <https://www-miklip.dkrz.de/about/problems/>`__ and
  `this <https://www-miklip.dkrz.de/about/murcss/>`__ page for additional resources
  on scoring from MurCSS.
* `properscoring <https://github.com/TheClimateCorporation/properscoring>`_:
  Probabilistic forecast metrics in python.
  (We've since wrapped these functions in ``xskillscore``)
* `pySTEPS <https://pysteps.github.io/>`_:
  Framework for short-term ensemble forecasting of precipitation.
* `S2D Verification <https://cran.r-project.org/web/packages/s2dverification/s2dverification.pdf>`_:
  An R package for a common set of tools for forecast verification.
* `SwirlsPy <https://docs.com-swirls.org/latest/>`_:
  Analysis and prediction of nowcasts for precipitation and weather phenomena.
* `xskillscore <https://xskillscore.readthedocs.io>`_:
  Metrics for verifying forecasts (a key dependency to ``climpred``).
